@@ -86,23 +86,30 @@ class SST1RSoXSDB:
         q = RawMongo(**kwargs)
         return self.c.search(q)
     
-    def loadRun(self,run,dims,coords={}):
+    def loadRun(self,run,dims=None,coords={}):
         '''
         Loads a run entry from a catalog result into a raw xarray.
 
         Args:
             run (DataBroker result): a single run from BlueSky
-            dims (list): list of dimensions you'd like in the resulting xarray.  See list of allowed dimensions in documentation.
+            dims (list): list of dimensions you'd like in the resulting xarray.  See list of allowed dimensions in documentation.  If not set or None, tries to auto-hint the dims from the RSoXS plan_name.
             coords (dict): user-supplied dimensions, see syntax examples in documentation.
 
         Returns:
             raw (xarray): raw xarray containing your scan in PyHyper-compliant format
 
         '''
-        md = self.loadMd(run)  
-
-        
-
+        md = self.loadMd(run)
+        if 'NEXAFS' in md['start']['plan_name']:
+            raise NotImplementedError(f"Scan {md['start']['scan_id']} is a {md['start']['plan_name']} NEXAFS scan.  NEXAFS loading is not yet supported.")
+        elif ('full' in md['start']['plan_name'] or 'short' in md['start']['plan_name']) and dims is None:
+            dims = ['energy']
+        elif 'spiralsearch' in md['start']['plan_name'] and dims is None:
+            dims = ['sam_x','sam_y']
+        elif 'count' in md['start']['plan_name'] and dims is None:
+            dims = ['epoch']
+        elif dims is None:
+            raise NotImplementedError(f"Cannot infer dimensions for a {md['start']['plan_name']} plan.  If this should be broadly supported, please raise an issue with the expected dimensions on the project GitHub.")
         #data = run['primary']['data'][md['detector']+'_image'] 
         #if self.dark_subtract:
         #    dark = run['dark']['data'][md['detector']+'_image'].mean('time') #@TODO: change to correct dark indexing
@@ -146,6 +153,9 @@ class SST1RSoXSDB:
                 dims_to_join,
                 names=dim_names_to_join)
 
+        #handle the edge case of a partly-finished scan
+        if len(index) != len(data['time']):
+            index = index[:len(data['time'])]
         retxr = data.squeeze('dim_0').rename({'dim_1':'pix_y','dim_2':'pix_x'}).rename({'time':'system'}).assign_coords(system=index)#,md['detector']+'_image':'intensity'})
         
         #this is needed for holoviews compatibility, hopefully does not break other features.
@@ -154,10 +164,11 @@ class SST1RSoXSDB:
         retxr.attrs.update(md)
         
         # deal with the edge case where the LAST energy of a run is repeated... this may need modification to make it correct (did the energies shift when this happened??)
-        
-        if retxr.system[-1] == retxr.system[-2]:
-            retxr = retxr[:-1]
-            
+        try:
+            if retxr.system[-1] == retxr.system[-2]:
+                retxr = retxr[:-1]
+        except IndexError:
+            pass
         
         return retxr
 
@@ -208,7 +219,7 @@ class SST1RSoXSDB:
                 md['sdd'] = run.start['RSoXS_WAXS_SDD']
 
         else:
-            md['rsoxs_config'] == 'unknown'
+            md['rsoxs_config'] = 'unknown'
             warnings.warn(f'RSoXS_Config is neither SAXS or WAXS. Looks to be {start["RSoXS_Config"]}.  Might want to check that out.',stacklevel=2)
 
         if md['rsoxs_config']=='saxs':
@@ -223,8 +234,10 @@ class SST1RSoXSDB:
         baseline = run['baseline']['data']
 
         # items coming from primary
-        primary = run['primary']['data']
-
+        try:
+            primary = run['primary']['data']
+        except KeyError:
+            raise Exception('No primary stream --> probably you caught run before image was written.  Try again.')
         md_lookup = {
             'sam_x':'RSoXS Sample Outboard-Inboard',
             'sam_y':'RSoXS Sample Up-Down',
@@ -248,6 +261,7 @@ class SST1RSoXSDB:
                 except KeyError:
                     warnings.warn(f'Could not find {rsoxs} in either baseline or primary.  Needed to infill value {phs}.  Setting to None.',stacklevel=2)
                     md[phs] = None
+        md['epoch'] = md['meas_time'].timestamp()
                     
         md['wavelength'] = 1.239842e-6 / md['energy']
         #md['sampleid'] = scan_id@todo this should be easy
